@@ -19,9 +19,8 @@ from typing import Optional
 
 from selenium.webdriver.chromium.webdriver import ChromiumDriver
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
-
-from .options import Options
-from .service import Service
+from selenium.webdriver.edge.options import Options
+from selenium.webdriver.edge.service import Service
 
 
 class WebDriver(ChromiumDriver):
