@@ -21,8 +21,7 @@ from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.remote.webdriver import WebDriver
 from selenium.webdriver.remote.webelement import WebElement
-
-from .abstract_event_listener import AbstractEventListener
+from selenium.webdriver.support.abstract_event_listener import AbstractEventListener
 
 
 def _wrap_elements(result, ef_driver):
